package org.luo3.springrestdemo;

import java.util.HashMap;
import java.util.Map;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

// @RestController 标记为 RestAPI 控制器
@RestController
public class AppController {

  // 基本 HTTP GET
  @GetMapping("/hi")
  public Map<String, String> handleBaseHTTPGET () {
    return new HashMap<>(){{
      put("msg", "hi");
    }};
  }

  // URL Query
  @GetMapping("/hello")
  public Map<String, String> handleURLQuery (@RequestParam("name") String name) {
    return new HashMap<>(){{
      put("msg", "hi, " + name);
    }};
  }

  // JSON body
  @PostMapping(
    path = "/hello",
    consumes = "application/json", 
    produces = "application/json"
  )
  public Map<String,Object> handleJSONBody (@RequestBody Map<String,Object> jsonObject) {
    String name = jsonObject.get("name").toString();
    return new HashMap<>(){{
      put("msg", "welcome back, " + name);
    }};
  }

  // 占位符
  @GetMapping("/profile/{slug}")
  public Map<String, String> handlePathVariable (@PathVariable("slug") String slugValue) {
    return new HashMap<>(){{
      put("msg", "profile of user: " + slugValue);
    }};
  }

}

